# xrd-image-util
Utility package for handling XRD image data.

## About
`xrd-image-util` aims to provide (i) a lightweight interface for Bluesky data handling, (ii) an arsenal of tools for analyzing XRD image data, and (iii) options for exporting XRD image data. In its current form, `xrd-image-util` is tailored for data gathering at APS beamline 6-ID-B.

## Prerequisites
- Python 3.8+
- Anaconda installations of Python are recommended

## Getting Started
The package can be installed via PyPI with the following shell command:

```pip install xrd-image-util```

## Execution
The package can be imported in-line with the following line of code (the alias of `xiu` is not required):

```import xrdimageutil as xiu```

See the `demos` subdirectory for basic use cases.

## License
See [`LICENSE.txt`](https://github.com/henryjsmith12/xrd-image-util/blob/main/LICENSE) for more information.

## Author
[Henry Smith](https://www.linkedin.com/in/henry-smith-5956a0189/) - Co-op Student Technical at Argonne National Laboratory

## Support
* [Report bugs here](https://github.com/henryjsmith12/xrd-image-util/issues)
* Email author at [smithh@anl.gov](smithh@anl.gov)
